==> campsite-2.6.1.tar.gz: campsite/implementation/management/priv/lang/sr/article_images.php <==
<?php 
regGS("You do not have the right to change image information.", "");
regGS("The image number specified is already in use.", "");
regGS("The image has been removed from the article.", "");
regGS("Image '$1' updated.", "");
regGS("Image '$1' added.", "");
regGS("Edit article", "Уреди текст");
regGS("You do not have the right to attach images to articles.", "Немате право да качите слике уз текстове.");
regGS("You do not have the right to add images.", "Немате право да додајете слике.");
regGS("Image information", "Подаци о слици");
regGS("Attach New Image", "Прикачи нову слику");
regGS("Attach Image To Article", "Прикачи слику уз текст");
regGS("Attach Existing Image", "Прикачи постојећу слику");
regGS("Add New Image", "Додај нову слику");
regGS("Date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Датум<br><small>(гггг-мм-дд)</small>");
regGS("Please enter a number for the image.", "Унесите број за слику");
regGS("Please enter a description for the image.", "Унесите опис слике.");
regGS("You must select an image file to upload.", "Морате изабрати слику коју желите да аплоудујете.");
regGS("Change image information", "Промени податке о слици");
regGS("You do not have the right to add images", "Немате право да додајете слике");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Да ли сте сигурни да желите да уконите слику \'$1\' из текста?");
regGS("Delete image $1", "Избриши слику $1");
regGS("Click one of the ", "Кликните на један од понуђених 'додај слику'линкова");
regGS("Are you sure you want to delete the image '$1'?", "Да ли сте сигурни да желите да обришете слику '$1'?");
regGS("Unlink image $1", "Уклони везу слике $1");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/sr/article_images.php <==
<?php 
regGS("Unable to add new image.", "Није могуће додати нову слику");
regGS("Image number '$1' already exists", "Број слике '$1' већ постоји");
regGS("You do not have the right to change image information.", "Немате право да мењате податке о слици");
regGS("The image number specified is already in use.", "Тај број за слику је већ у употреби");
regGS("The image has been removed from the article.", "Слика је уклоњена из чланка");
regGS("Image '$1' updated.", "Слика '$1'изменњена");
regGS("Image '$1' added.", "Слика '$1'додата");
regGS("Edit article", "Уреди текст");
regGS("You do not have the right to attach images to articles.", "Немате право да качите слике уз текстове.");
regGS("You do not have the right to add images.", "Немате право да додајете слике.");
regGS("Image information", "Подаци о слици");
regGS("Attach New Image", "Прикачи нову слику");
regGS("Attach Image To Article", "Прикачи слику уз текст");
regGS("Attach Existing Image", "Прикачи постојећу слику");
regGS("Add New Image", "Додај нову слику");
regGS("Date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Датум<br><small>(гггг-мм-дд)</small>");
regGS("Please enter a number for the image.", "Унесите број за слику");
regGS("Please enter a description for the image.", "Унесите опис слике.");
regGS("You must select an image file to upload.", "Морате изабрати слику коју желите да аплоудујете.");
regGS("Change image information", "Промени податке о слици");
regGS("You do not have the right to add images", "Немате право да додајете слике");
regGS("Are you sure you want to remove the image \'$1\' from the article?", "Да ли сте сигурни да желите да уконите слику \'$1\' из текста?");
regGS("Delete image $1", "Избриши слику $1");
regGS("Click one of the ", "Кликните на један од понуђених 'додај слику'линкова");
regGS("Are you sure you want to delete the image '$1'?", "Да ли сте сигурни да желите да обришете слику '$1'?");
regGS("Unlink image $1", "Уклони везу слике $1");
regGS("Are you sure you want to remove the image \\'$1\\' from the article?", "Да ли сте сигурни да желите да уконите слику \\'$1\\' из текста?");
?>
